akhdefo_functions.akhdefo_ts_plot — Akhdefo software documentation

# akhdefo_functions.akhdefo_ts_plot

akhdefo_functions.akhdefo_ts_plot(path_to_shapefile='', dem_path='', point_size=1.0, opacity=0.75, cmap='turbo', Set_fig_MinMax=True, MinMaxRange=[-50, 50], color_field='VEL', user_data_points='', path_saveData_points='', save_plot=False, Fig_outputDir='', VEL_Scale='year')

  This program used for analysis time-series velocity profiles

  ## Parameters

  user_data_pointsstr

    provide path to csv. file contains x and y coordinate for points of interest you can generate this file by providing path to path_saveData_points (POI.csv). This is useful to save mouse click positions to repeat the plots for different datasets for example if you plot several TS profiles for EW velocity product, you can recreate TS for the same exact position by saving POI.csv with path_saveData_points and then use that as input for the another plot such as NS velocity product via setting user_datapoints=”POI.csv”

  path_to_shapefilestr

    type path to timeseries shapefile in stack_data/TS folder

  dem_pathstr

    path to dem raster in geotif fromat

  point_sizefloat

    size of the sactter plot points

  opacityfloat

    transparency of the scater overlay

  cmapstr

    Matplotlib colormap options example “RdYlBu_r, jet, turbo, hsv, etc…”

  Set_fig_MinMaxbool

    True or False

  MinMaxRangelist

    [-50,50] Normalize plot colormap range if Set_fig_MinMax=True

  color_fieldstr

    ‘VEL’ ,”VEL_2D”, ‘VEL_N’, ‘VEL_E’, ‘VELDir_MEA’

  path_saveData_pointsstr

    optional, provide directory path if you want to save profile data. the data will be saved under POI.csv file

  save_plot: bool

    True or False

  Fig_outputDirstr

    > if save_plot=True then you save your profile plots in interactive html file and jpg image

    VEL_Scalestr

      ‘year’ or ‘month’ projects the velocity into provided time-scale

  ## Returns

  Interactive Figures